Bumped Mbed FW version to 01.20.0080

Revision:
5:0728bde67bdb
Parent:
0:85855ecd3257
Child:
10:14954555be2a
--- a/main.cpp	Tue Jun 04 10:09:11 2019 +0000
+++ b/main.cpp	Wed Jun 05 05:39:15 2019 +0000
@@ -73,67 +73,56 @@
  *
  */
 #include "mbed.h"
-#include "adi_sense_api.h"
-#include "adi_sense_1000/adi_sense_1000_api.h"
-#include "adi_sense_log.h"
+#include "admw_api.h"
+#include "admw1001/admw1001_api.h"
+#include "admw_log.h"
 #include "common/utils.h"
 #include "common/platform.h"
 
-extern ADI_SENSE_CONFIG cjc0_thermistor_10k_ntc_config;
-extern ADI_SENSE_CONFIG sensor0_rtd_2w_pt100_config;
-extern ADI_SENSE_CONFIG sensor0_microphone_config;
-extern ADI_SENSE_CONFIG sensor0_diode_2c_config;
-extern ADI_SENSE_CONFIG sensor0_typeK_cjc0_config;
-extern ADI_SENSE_CONFIG sensor1_rtd_3w_pt100_config;
-extern ADI_SENSE_CONFIG sensor1_diode_3c_config;
-extern ADI_SENSE_CONFIG sensor2_typeT_cjc0_config;
-extern ADI_SENSE_CONFIG sensor2_bridge_6w_pressure_config;
-extern ADI_SENSE_CONFIG sensor3_typeJ_cjc0_config;
-extern ADI_SENSE_CONFIG sensor3_thermistor_10k_ntc_config;
-extern ADI_SENSE_CONFIG voltage_honeywellPressure_config;
-extern ADI_SENSE_CONFIG current_honeywellPressure_config;
-extern ADI_SENSE_CONFIG i2c0_honeywellHumidicon_config;
-extern ADI_SENSE_CONFIG i2c0_sensirionSHT3X_config;
-extern ADI_SENSE_CONFIG i2c0_onsemiNOA1305_config;
-extern ADI_SENSE_CONFIG spi0_honeywellTrustability_config;
-extern ADI_SENSE_CONFIG spi0_adiAdxl362_config;
-extern ADI_SENSE_CONFIG spi0_adiAdxl355_config;
-extern ADI_SENSE_CONFIG uart_cozirCO2_config;
-extern ADI_SENSE_CONFIG multichannel_continuous_config;
-extern ADI_SENSE_CONFIG multichannel_multicycle_config;
-extern ADI_SENSE_CONFIG multichannel_singlecycle_config;
+
+
+
+extern ADMW_CONFIG sensor0_typeK_cjc0_config;
+extern ADMW_CONFIG sensor1_rtd_3w_pt100_config;
+extern ADMW_CONFIG sensor2_typeT_cjc0_config;
+extern ADMW_CONFIG sensor3_typeJ_cjc0_config;
+extern ADMW_CONFIG i2c0_sensirionSHT3X_config;
+extern ADMW_CONFIG spi0_adiAdxl362_config;
+extern ADMW_CONFIG multichannel_continuous_config;
+extern ADMW_CONFIG multichannel_multicycle_config;
+extern ADMW_CONFIG multichannel_singlecycle_config;
 
 /* Change the following pointer to select any of the configurations above */
-static ADI_SENSE_CONFIG *pSelectedConfig = &sensor0_typeK_cjc0_config;
+static ADMW_CONFIG *pSelectedConfig = &sensor0_typeK_cjc0_config;
 
-static ADI_SENSE_CONNECTION connectionInfo = PLATFORM_CONNECTION_INFO;
+static ADMW_CONNECTION connectionInfo = PLATFORM_CONNECTION_INFO;
 
 int main()
 {
-    ADI_SENSE_RESULT res;
-    ADI_SENSE_STATUS status;
-    ADI_SENSE_DEVICE_HANDLE hDevice;
-    ADI_SENSE_MEASUREMENT_MODE eMeasurementMode = ADI_SENSE_MEASUREMENT_MODE_NORMAL;
+    ADMW_RESULT res;
+    ADMW_STATUS status;
+    ADMW_DEVICE_HANDLE hDevice;
+    ADMW_MEASUREMENT_MODE eMeasurementMode = ADMW_MEASUREMENT_MODE_NORMAL;
     bool bDeviceReady;
 
     /*
      * Open an ADI Sense device instance.
      */
-    res = adi_sense_Open(0, &connectionInfo, &hDevice);
-    if (res != ADI_SENSE_SUCCESS)
+    res = admw_Open(0, &connectionInfo, &hDevice);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to open device instance");
+        ADMW_LOG_ERROR("Failed to open device instance");
         return res;
     }
 
     /*
      * Reset the given ADI Sense device....
      */
-    ADI_SENSE_LOG_INFO("Resetting ADI Sense device, please wait...");
-    res = adi_sense_Reset(hDevice);
-    if (res != ADI_SENSE_SUCCESS)
+    ADMW_LOG_INFO("Resetting ADI Sense device, please wait...");
+    res = admw_Reset(hDevice);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to reset device");
+        ADMW_LOG_ERROR("Failed to reset device");
         return res;
     }
     /*
@@ -141,43 +130,43 @@
      */
     do {
         wait_ms(100);
-        res = adi_sense_GetDeviceReadyState(hDevice, &bDeviceReady);
-        if (res != ADI_SENSE_SUCCESS)
+        res = admw_GetDeviceReadyState(hDevice, &bDeviceReady);
+        if (res != ADMW_SUCCESS)
         {
-            ADI_SENSE_LOG_ERROR("Failed to get device ready-state");
+            ADMW_LOG_ERROR("Failed to get device ready-state");
             return res;
         }
     } while (! bDeviceReady);
-    ADI_SENSE_LOG_INFO("ADI Sense device ready");
+    ADMW_LOG_INFO("ADI Sense device ready");
 
     /*
      * Write configuration settings to the device registers.
      * Settings are not applied until adi_sense_ApplyConfigUpdates() is called.
      */
-    ADI_SENSE_LOG_INFO("Setting device configuration");
-    res = adi_sense_SetConfig(hDevice, pSelectedConfig);
-    if (res != ADI_SENSE_SUCCESS)
+    ADMW_LOG_INFO("Setting device configuration");
+    res = admw_SetConfig(hDevice, pSelectedConfig);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to set device configuration");
+        ADMW_LOG_ERROR("Failed to set device configuration");
         return res;
     }
-    res = adi_sense_ApplyConfigUpdates(hDevice);
-    if (res != ADI_SENSE_SUCCESS)
+    res = admw_ApplyConfigUpdates(hDevice);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to apply device configuration");
+        ADMW_LOG_ERROR("Failed to apply device configuration");
         return res;
     }
     /*
      * Check device status after updating the configuration
      */
-    res = adi_sense_GetStatus(hDevice, &status);
-    if (res != ADI_SENSE_SUCCESS)
+    res = admw_GetStatus(hDevice, &status);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to retrieve device status");
+        ADMW_LOG_ERROR("Failed to retrieve device status");
         return res;
     }
     if (status.deviceStatus &
-        (ADI_SENSE_DEVICE_STATUS_ERROR | ADI_SENSE_DEVICE_STATUS_ALERT))
+        (ADMW_DEVICE_STATUS_ERROR | ADMW_DEVICE_STATUS_ALERT))
     {
         utils_printStatus(&status);
     }
@@ -185,16 +174,16 @@
     /*
      * Kick off the measurement cycle here
      */
-    ADI_SENSE_LOG_INFO("Configuration completed, starting measurement cycles");
+    ADMW_LOG_INFO("Configuration completed, starting measurement cycles");
     utils_runMeasurement(hDevice, eMeasurementMode);
 
     /*
      * Clean up and exit
      */
-    res = adi_sense_Close(hDevice);
-    if (res != ADI_SENSE_SUCCESS)
+    res = admw_Close(hDevice);
+    if (res != ADMW_SUCCESS)
     {
-        ADI_SENSE_LOG_ERROR("Failed to close device instance");
+        ADMW_LOG_ERROR("Failed to close device instance");
         return res;
     }
@@ -141,43 +130,43 @@
     /*
      * Write configuration settings to the device registers.
-     * Settings are not applied until adi_sense_ApplyConfigUpdates() is called.
+     * Settings are not applied until admw_ApplyConfigUpdates() is called.
      */